@@ -1,6 +1,6 @@
 /* global.c  -	global control functions
  * Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003
- *               2004, 2005, 2006, 2008  Free Software Foundation, Inc.
+ *               2004, 2005, 2006, 2008, 2011  Free Software Foundation, Inc.
  *
  * This file is part of Libgcrypt.
  *
@@ -47,16 +47,30 @@
 static unsigned int debug_flags;
 
 /* gcry_control (GCRYCTL_SET_FIPS_MODE), sets this flag so that the
-   intialization code swicthed fips mode on.  */
+   initialization code switched fips mode on.  */
 static int force_fips_mode;
 
-/* If this flag is set, the application may no longer assume that the
-   process is running in FIPS mode.  */
-static int inactive_fips_mode;
-
 /* Controlled by global_init().  */
 static int any_init_done;
 
+/* A table to map hardware features to a string.  */
+static struct
+{
+  unsigned int flag;
+  const char *desc;
+} hwflist[] =
+  {
+    { HWF_PADLOCK_RNG, "padlock-rng" },
+    { HWF_PADLOCK_AES, "padlock-aes" },
+    { HWF_PADLOCK_SHA, "padlock-sha" },
+    { HWF_PADLOCK_MMUL,"padlock-mmul"},
+    { HWF_INTEL_AESNI, "intel-aesni" },
+    { 0, NULL}
+  };
+
+/* A bit vector with the hardware features which shall not be used.
+   This variable must be set prior to any initialization.  */
+static unsigned int disabled_hw_features;
 
 
 /* Memory management. */
@@ -91,14 +105,14 @@ global_init (void)
   err = ath_init ();
   if (err)
     goto fail;
-  
+
   /* See whether the system is in FIPS mode.  This needs to come as
      early as possible put after the ATH has been initialized.  */
   _gcry_initialize_fips_mode (force_fips_mode);
 
   /* Before we do any other initialization we need to test available
      hardware features.  */
-  _gcry_detect_hw_features ();
+  _gcry_detect_hw_features (disabled_hw_features);
 
   err = _gcry_cipher_init ();
   if (err)
@@ -130,7 +144,7 @@ global_init (void)
    sure that the minimal initialization has been done.  This is far
    from a perfect solution and hides problems with an improper
    initialization but at least in single-threaded mode it should work
-   reliable. 
+   reliable.
 
    The reason we need this is that a lot of applications don't use
    Libgcrypt properly by not running any initialization code at all.
@@ -163,7 +177,7 @@ _gcry_global_is_operational (void)
 /* Version number parsing.  */
 
 /* This function parses the first portion of the version number S and
-   stores it in *NUMBER.  On sucess, this function returns a pointer
+   stores it in *NUMBER.  On success, this function returns a pointer
    into S starting with the first character, which is not part of the
    initial number portion; on failure, NULL is returned.  */
 static const char*
@@ -220,7 +234,7 @@ gcry_check_version( const char *req_version )
     const char *ver = VERSION;
     int my_major, my_minor, my_micro;
     int rq_major, rq_minor, rq_micro;
-    const char *my_plvl, *rq_plvl;
+    const char *my_plvl;
 
     /* Initialize library.  */
     global_init ();
@@ -236,23 +250,19 @@ gcry_check_version( const char *req_version )
 	   assert() here and bail out in case this happens?  -mo.  */
 	return NULL;
 
-  /* Parse requested version number.  */
-    rq_plvl = parse_version_string( req_version, &rq_major, &rq_minor,
-								&rq_micro );
-    if ( !rq_plvl )
-        /* req version string is invalid, this can happen.  */
-	return NULL;
+    /* Parse requested version number.  */
+    if (!parse_version_string (req_version, &rq_major, &rq_minor, &rq_micro))
+      return NULL;  /* req version string is invalid, this can happen.  */
 
     /* Compare version numbers.  */
     if ( my_major > rq_major
 	|| (my_major == rq_major && my_minor > rq_minor)
+	|| (my_major == rq_major && my_minor == rq_minor		                           		 && my_micro > rq_micro)
 	|| (my_major == rq_major && my_minor == rq_minor
-				 && my_micro > rq_micro)
-	|| (my_major == rq_major && my_minor == rq_minor
-				 && my_micro == rq_micro
-				 && strcmp( my_plvl, rq_plvl ) >= 0) ) {
+                                 && my_micro == rq_micro))
+      {
 	return ver;
-    }
+      }
 
     return NULL;
 }
@@ -262,15 +272,6 @@ static void
 print_config ( int (*fnc)(FILE *fp, const char *format, ...), FILE *fp)
 {
   unsigned int hwf;
-  struct {
-    unsigned int flag;
-    const char *desc;
-  } hwflist[] = {
-    { HWF_PADLOCK_RNG, "padlock-rng" },
-    { HWF_PADLOCK_AES, "padlock-aes" },
-    { HWF_PADLOCK_SHA, "padlock-sha" },
-    { 0, NULL} 
-  };
   int i;
 
   fnc (fp, "version:%s:\n", VERSION);
@@ -295,13 +296,13 @@ print_config ( int (*fnc)(FILE *fp, const char *format, ...), FILE *fp)
   hwf = _gcry_get_hw_features ();
   fnc (fp, "hwflist:");
   for (i=0; hwflist[i].desc; i++)
-  if ( (hwf & hwflist[i].flag) )
-    fnc (fp, "%s:", hwflist[i].desc);
+    if ( (hwf & hwflist[i].flag) )
+      fnc (fp, "%s:", hwflist[i].desc);
   fnc (fp, "\n");
   /* We use y/n instead of 1/0 for the simple reason that Emacsen's
      compile error parser would accidently flag that line when printed
      during "make check" as an error.  */
-  fnc (fp, "fips-mode:%c:%c:\n", 
+  fnc (fp, "fips-mode:%c:%c:\n",
        fips_mode ()? 'y':'n',
        _gcry_enforced_fips_mode ()? 'y':'n' );
 }
@@ -316,7 +317,7 @@ _gcry_vcontrol (enum gcry_ctl_cmds cmd, va_list arg_ptr)
 {
   static int init_finished = 0;
   gcry_err_code_t err = 0;
-  
+
   switch (cmd)
     {
     case GCRYCTL_ENABLE_M_GUARD:
@@ -354,7 +355,7 @@ _gcry_vcontrol (enum gcry_ctl_cmds cmd, va_list arg_ptr)
     case GCRYCTL_DISABLE_SECMEM:
       global_init ();
       no_secure_memory = 1;
-      break;    
+      break;
 
     case GCRYCTL_INIT_SECMEM:
       global_init ();
@@ -454,7 +455,7 @@ _gcry_vcontrol (enum gcry_ctl_cmds cmd, va_list arg_ptr)
       _gcry_random_initialize (1);
 
       if ( fips_is_operational () )
-        _gcry_fast_random_poll (); 
+        _gcry_fast_random_poll ();
       break;
 
     case GCRYCTL_SET_RNDEGD_SOCKET:
@@ -475,10 +476,10 @@ _gcry_vcontrol (enum gcry_ctl_cmds cmd, va_list arg_ptr)
       _gcry_random_initialize (1);
       _gcry_use_random_daemon (!! va_arg (arg_ptr, int));
       break;
-      
+
       /* This command dumps information pertaining to the
          configuration of libgcrypt to the given stream.  It may be
-         used before the intialization has been finished but not
+         used before the initialization has been finished but not
          before a gcry_version_check. */
     case GCRYCTL_PRINT_CONFIG:
       {
@@ -495,14 +496,16 @@ _gcry_vcontrol (enum gcry_ctl_cmds cmd, va_list arg_ptr)
       break;
 
     case GCRYCTL_FIPS_MODE_P:
-      if (fips_mode () && !inactive_fips_mode && !no_secure_memory)
+      if (fips_mode ()
+          && !_gcry_is_fips_mode_inactive ()
+          && !no_secure_memory)
 	err = GPG_ERR_GENERAL; /* Used as TRUE value */
       break;
 
     case GCRYCTL_FORCE_FIPS_MODE:
       /* Performing this command puts the library into fips mode.  If
          the library has already been initialized into fips mode, a
-         selftest is triggered.  it is not possible to put the libraty
+         selftest is triggered.  It is not possible to put the libraty
          into fips mode after having passed the initialization. */
       if (!any_init_done)
         {
@@ -510,7 +513,7 @@ _gcry_vcontrol (enum gcry_ctl_cmds cmd, va_list arg_ptr)
              into fips mode during initialization.  */
           force_fips_mode = 1;
         }
-      else 
+      else
         {
           /* Already initialized.  If we are already operational we
              run a selftest.  If not we use the is_operational call to
@@ -531,7 +534,11 @@ _gcry_vcontrol (enum gcry_ctl_cmds cmd, va_list arg_ptr)
       err = _gcry_fips_run_selftests (1);
       break;
 
-    case 58:
+#if _GCRY_GCC_VERSION >= 40600
+# pragma GCC diagnostic push
+# pragma GCC diagnostic ignored "-Wswitch"
+#endif
+    case 58:  /* Init external random test.  */
       {
         void **rctx        = va_arg (arg_ptr, void **);
         unsigned int flags = va_arg (arg_ptr, unsigned int);
@@ -548,7 +555,7 @@ _gcry_vcontrol (enum gcry_ctl_cmds cmd, va_list arg_ptr)
                                                  seed, seedlen, dt, dtlen);
       }
       break;
-    case 59:
+    case 59:  /* Run external random test.  */
       {
         void *ctx     = va_arg (arg_ptr, void *);
         void *buffer  = va_arg (arg_ptr, void *);
@@ -559,15 +566,39 @@ _gcry_vcontrol (enum gcry_ctl_cmds cmd, va_list arg_ptr)
           err = _gcry_random_run_external_test (ctx, buffer, buflen);
       }
       break;
-    case 60:
+    case 60:  /* Deinit external random test.  */
       {
         void *ctx = va_arg (arg_ptr, void *);
         _gcry_random_deinit_external_test (ctx);
       }
       break;
+    case 61:  /* RFU */
+      break;
+    case 62:  /* RFU */
+      break;
+#if _GCRY_GCC_VERSION >= 40600
+# pragma GCC diagnostic pop
+#endif
 
+    case GCRYCTL_DISABLE_HWF:
+      {
+        const char *name = va_arg (arg_ptr, const char *);
+        int i;
+
+        for (i=0; hwflist[i].desc; i++)
+          if (!strcmp (hwflist[i].desc, name))
+            {
+              disabled_hw_features |= hwflist[i].flag;
+              break;
+            }
+        if (!hwflist[i].desc)
+          err = GPG_ERR_INV_NAME;
+      }
+      break;
 
     default:
+      /* A call to make sure that the dummy code is linked in.  */
+      _gcry_compat_identification ();
       err = GPG_ERR_INV_OP;
     }
 
@@ -582,7 +613,7 @@ gcry_control (enum gcry_ctl_cmds cmd, ...)
 {
   gcry_error_t err;
   va_list arg_ptr;
-  
+
   va_start (arg_ptr, cmd);
   err = _gcry_vcontrol (cmd, arg_ptr);
   va_end(arg_ptr);
@@ -625,7 +656,7 @@ gcry_err_code_to_errno (gcry_err_code_t code)
   return gpg_err_code_from_errno (code);
 }
 
-  
+
 /* Return an error value with the error source SOURCE and the system
    error ERR.  */
 gcry_error_t
@@ -658,20 +689,10 @@ gcry_set_allocation_handler (gcry_handler_alloc_t new_alloc_func,
 
   if (fips_mode ())
     {
-      if (_gcry_enforced_fips_mode () )
-        {
-          /* Get us into the error state. */
-          fips_signal_error ("custom allocation handler used");
-          return;
-        }
       /* We do not want to enforce the fips mode, but merely set a
-         flag so that the application may check wheter it is still in
+         flag so that the application may check whether it is still in
          fips mode.  */
-      inactive_fips_mode = 1;
-#ifdef HAVE_SYSLOG
-      syslog (LOG_USER|LOG_WARNING, "Libgcrypt warning: "
-              "custom allocation handler used - FIPS mode disabled");
-#endif /*HAVE_SYSLOG*/
+      _gcry_inactivate_fips_mode ("custom allocation handler");
     }
 
   alloc_func = new_alloc_func;
@@ -708,7 +729,7 @@ gcry_set_outofcore_handler( int (*f)( void*, size_t, unsigned int ),
       log_info ("out of core handler ignored in FIPS mode\n");
       return;
     }
-  
+
   outofcore_handler = f;
   outofcore_handler_value = value;
 }
@@ -754,7 +775,7 @@ do_malloc (size_t n, unsigned int flags, void **mem)
       /* Make sure that ERRNO has been set in case a user supplied
          memory handler didn't it correctly. */
       if (!errno)
-        errno = ENOMEM;
+        gpg_err_set_errno (ENOMEM);
       err = gpg_err_code_from_errno (errno);
     }
   else
@@ -762,7 +783,7 @@ do_malloc (size_t n, unsigned int flags, void **mem)
 
   return err;
 }
-  
+
 void *
 gcry_malloc (size_t n)
 {
@@ -797,7 +818,7 @@ void
 _gcry_check_heap( const void *a )
 {
   (void)a;
-  
+
     /* FIXME: implement this*/
 #if 0
     if( some_handler )
@@ -812,25 +833,44 @@ gcry_realloc (void *a, size_t n)
 {
   void *p;
 
+  /* To avoid problems with non-standard realloc implementations and
+     our own secmem_realloc, we divert to malloc and free here.  */
+  if (!a)
+    return gcry_malloc (n);
+  if (!n)
+    {
+      gcry_free (a);
+      return NULL;
+    }
+
   if (realloc_func)
     p = realloc_func (a, n);
   else
     p =  _gcry_private_realloc (a, n);
   if (!p && !errno)
-    errno = ENOMEM;
+    gpg_err_set_errno (ENOMEM);
   return p;
 }
 
 void
-gcry_free( void *p )
+gcry_free (void *p)
 {
-  if( !p )
+  int save_errno;
+
+  if (!p)
     return;
 
+  /* In case ERRNO is set we better save it so that the free machinery
+     may not accidently change ERRNO.  We restore it only if it was
+     already set to comply with the usual C semantic for ERRNO.  */
+  save_errno = errno;
   if (free_func)
     free_func (p);
   else
     _gcry_private_free (p);
+
+  if (save_errno)
+    gpg_err_set_errno (save_errno);
 }
 
 void *
@@ -841,9 +881,9 @@ gcry_calloc (size_t n, size_t m)
 
   bytes = n * m; /* size_t is unsigned so the behavior on overflow is
                     defined. */
-  if (m && bytes / m != n) 
+  if (m && bytes / m != n)
     {
-      errno = ENOMEM;
+      gpg_err_set_errno (ENOMEM);
       return NULL;
     }
 
@@ -861,12 +901,12 @@ gcry_calloc_secure (size_t n, size_t m)
 
   bytes = n * m; /* size_t is unsigned so the behavior on overflow is
                     defined. */
-  if (m && bytes / m != n) 
+  if (m && bytes / m != n)
     {
-      errno = ENOMEM;
+      gpg_err_set_errno (ENOMEM);
       return NULL;
     }
-  
+
   p = gcry_malloc_secure (bytes);
   if (p)
     memset (p, 0, bytes);
@@ -890,7 +930,7 @@ gcry_strdup (const char *string)
     string_cp = gcry_malloc_secure (string_n + 1);
   else
     string_cp = gcry_malloc (string_n + 1);
-  
+
   if (string_cp)
     strcpy (string_cp, string);
 
@@ -902,10 +942,10 @@ void *
 gcry_xmalloc( size_t n )
 {
   void *p;
-  
-  while ( !(p = gcry_malloc( n )) ) 
+
+  while ( !(p = gcry_malloc( n )) )
     {
-      if ( fips_mode () 
+      if ( fips_mode ()
            || !outofcore_handler
            || !outofcore_handler (outofcore_handler_value, n, 0) )
         {
@@ -919,7 +959,7 @@ void *
 gcry_xrealloc( void *a, size_t n )
 {
   void *p;
-  
+
   while ( !(p = gcry_realloc( a, n )) )
     {
       if ( fips_mode ()
@@ -937,8 +977,8 @@ void *
 gcry_xmalloc_secure( size_t n )
 {
   void *p;
-  
-  while ( !(p = gcry_malloc_secure( n )) ) 
+
+  while ( !(p = gcry_malloc_secure( n )) )
     {
       if ( fips_mode ()
            || !outofcore_handler
@@ -958,10 +998,10 @@ gcry_xcalloc( size_t n, size_t m )
   size_t nbytes;
   void *p;
 
-  nbytes = n * m; 
-  if (m && nbytes / m != n) 
+  nbytes = n * m;
+  if (m && nbytes / m != n)
     {
-      errno = ENOMEM;
+      gpg_err_set_errno (ENOMEM);
       _gcry_fatal_error(gpg_err_code_from_errno (errno), NULL );
     }
 
@@ -976,10 +1016,10 @@ gcry_xcalloc_secure( size_t n, size_t m )
   size_t nbytes;
   void *p;
 
-  nbytes = n * m; 
-  if (m && nbytes / m != n) 
+  nbytes = n * m;
+  if (m && nbytes / m != n)
     {
-      errno = ENOMEM;
+      gpg_err_set_errno (ENOMEM);
       _gcry_fatal_error(gpg_err_code_from_errno (errno), NULL );
     }
 
@@ -992,15 +1032,15 @@ char *
 gcry_xstrdup (const char *string)
 {
   char *p;
-  
-  while ( !(p = gcry_strdup (string)) ) 
+
+  while ( !(p = gcry_strdup (string)) )
     {
       size_t n = strlen (string);
       int is_sec = !!gcry_is_secure (string);
-      
+
       if (fips_mode ()
           || !outofcore_handler
-          || !outofcore_handler (outofcore_handler_value, n, is_sec) ) 
+          || !outofcore_handler (outofcore_handler_value, n, is_sec) )
         {
           _gcry_fatal_error (gpg_err_code_from_errno (errno),
                              is_sec? _("out of core in secure memory"):NULL);
@@ -1022,7 +1062,7 @@ _gcry_get_debug_flag (unsigned int mask)
 
 
 /* It is often useful to get some feedback of long running operations.
-   This function may be used to register a handler for this. 
+   This function may be used to register a handler for this.
    The callback function CB is used as:
 
    void cb (void *opaque, const char *what, int printchar,
@@ -1051,10 +1091,10 @@ _gcry_get_debug_flag (unsigned int mask)
                   ':'
            Restart with a new random value
                   '+'
-           Rabin Miller test passed          
+           Rabin Miller test passed
    "pk_elg"        '+','-','.','\n'   0  0
             Only used in debugging mode.
-   "pk_dsa"       
+   "pk_dsa"
             Only used in debugging mode.
 */
 void
